==> cxf-services-xkms-common-3.3.12-sources.jar: org/apache/cxf/xkms/model/xkms/PrototypeKeyBindingType.java <==

package org.apache.cxf.xkms.model.xkms;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * &lt;p&gt;Java class for PrototypeKeyBindingType complex type.
 * 
 * &lt;p&gt;The following schema fragment specifies the expected content contained within this class.
 * 
 * &lt;pre&gt;
 * &amp;lt;complexType name="PrototypeKeyBindingType"&amp;gt;
 *   &amp;lt;complexContent&amp;gt;
 *     &amp;lt;extension base="{http://www.w3.org/2002/03/xkms#}KeyBindingAbstractType"&amp;gt;
 *       &amp;lt;sequence&amp;gt;
 *         &amp;lt;element ref="{http://www.w3.org/2002/03/xkms#}ValidityInterval" minOccurs="0"/&amp;gt;
 *         &amp;lt;element ref="{http://www.w3.org/2002/03/xkms#}RevocationCodeIdentifier" minOccurs="0"/&amp;gt;
 *       &amp;lt;/sequence&amp;gt;
 *     &amp;lt;/extension&amp;gt;
 *   &amp;lt;/complexContent&amp;gt;
 * &amp;lt;/complexType&amp;gt;
 * &lt;/pre&gt;
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "PrototypeKeyBindingType", propOrder = {
    "validityInterval",
    "revocationCodeIdentifier"
})
public class PrototypeKeyBindingType
    extends KeyBindingAbstractType
{

    @XmlElement(name = "ValidityInterval")
    protected ValidityIntervalType validityInterval;
    @XmlElement(name = "RevocationCodeIdentifier")
    protected byte[] revocationCodeIdentifier;

    /**
     * Gets the value of the validityInterval property.
     * 
     * @return
     *     possible object is
     *     {@link ValidityIntervalType }
     *     
     */
    public ValidityIntervalType getValidityInterval() {
        return validityInterval;
    }

    /**
     * Sets the value of the validityInterval property.
     * 
     * @param value
     *     allowed object is
     *     {@link ValidityIntervalType }
     *     
     */
    public void setValidityInterval(ValidityIntervalType value) {
        this.validityInterval = value;
    }

    /**
     * Gets the value of the revocationCodeIdentifier property.
     * 
     * @return
     *     possible object is
     *     byte[]
     */
    public byte[] getRevocationCodeIdentifier() {
        return revocationCodeIdentifier;
    }

    /**
     * Sets the value of the revocationCodeIdentifier property.
     * 
     * @param value
     *     allowed object is
     *     byte[]
     */
    public void setRevocationCodeIdentifier(byte[] value) {
        this.revocationCodeIdentifier = value;
    }

}

==> cxf-services-xkms-common-3.5.8-sources.jar: org/apache/cxf/xkms/model/xkms/PrototypeKeyBindingType.java <==

package org.apache.cxf.xkms.model.xkms;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for PrototypeKeyBindingType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="PrototypeKeyBindingType"&gt;
 *   &lt;complexContent&gt;
 *     &lt;extension base="{http://www.w3.org/2002/03/xkms#}KeyBindingAbstractType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element ref="{http://www.w3.org/2002/03/xkms#}ValidityInterval" minOccurs="0"/&gt;
 *         &lt;element ref="{http://www.w3.org/2002/03/xkms#}RevocationCodeIdentifier" minOccurs="0"/&gt;
 *       &lt;/sequence&gt;
 *     &lt;/extension&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "PrototypeKeyBindingType", propOrder = {
    "validityInterval",
    "revocationCodeIdentifier"
})
public class PrototypeKeyBindingType
    extends KeyBindingAbstractType
{

    @XmlElement(name = "ValidityInterval")
    protected ValidityIntervalType validityInterval;
    @XmlElement(name = "RevocationCodeIdentifier")
    protected byte[] revocationCodeIdentifier;

    /**
     * Gets the value of the validityInterval property.
     * 
     * @return
     *     possible object is
     *     {@link ValidityIntervalType }
     *     
     */
    public ValidityIntervalType getValidityInterval() {
        return validityInterval;
    }

    /**
     * Sets the value of the validityInterval property.
     * 
     * @param value
     *     allowed object is
     *     {@link ValidityIntervalType }
     *     
     */
    public void setValidityInterval(ValidityIntervalType value) {
        this.validityInterval = value;
    }

    /**
     * Gets the value of the revocationCodeIdentifier property.
     * 
     * @return
     *     possible object is
     *     byte[]
     */
    public byte[] getRevocationCodeIdentifier() {
        return revocationCodeIdentifier;
    }

    /**
     * Sets the value of the revocationCodeIdentifier property.
     * 
     * @param value
     *     allowed object is
     *     byte[]
     */
    public void setRevocationCodeIdentifier(byte[] value) {
        this.revocationCodeIdentifier = value;
    }

}
